CustomizableTimePickerWidget class

Customizable Time Picker

Inheritance

Constructors

CustomizableTimePickerWidget({Key? key, DateTime? initialTime, String timeFormat = defaultTimeFormat, DateTimePickerLocale locale = pickerLocaleDefault, DateTimePickerTheme pickerTheme = DateTimePickerTheme.defaultPickerTheme, DateValueCallback? onChange, bool looping = false, Widget? separatorWidget})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
initialTime → DateTime?
Initial time for the picker
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
locale → DateTimePickerLocale
Localule used to render data
final
looping → bool
Variable to set picker spiners looped or not
final
onChange → DateValueCallback?
Function that will be called when value changes
final
pickerTheme → DateTimePickerTheme
Picker visual theme
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
separatorWidget → Widget?
Widget to placed between rows
final
timeFormat → String
Time format for the picker
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<CustomizableTimePickerWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited